@@ -5,7 +5,7 @@
 
 // CRAN change 2012-12-10
 //extern void abort(void);
-#define abort() error("fatal error in mapproj")
+#define abort() Rf_error("fatal error in mapproj")
 
 /* these routines duplicate names found in map.c.  they are
 called from routines in hex.c, guyou.c, and tetra.c, which
